==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/acl/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author tomas@valenta.cz
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 * @author zbynek.krivka@seznam.cz
 * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
 * @author Jakub A. Těšínský (j@kub.cz)
 * @author mkucera66@seznam.cz
 */
$lang['admin_acl']             = 'Správa přístupových práv';
$lang['acl_group']             = 'Skupina';
$lang['acl_user']              = 'Uživatel';
$lang['acl_perms']             = 'Práva pro';
$lang['page']                  = 'Stránka';
$lang['namespace']             = 'Jmenný prostor';
$lang['btn_select']            = 'Vybrat';
$lang['p_user_id']             = 'Uživatel <b class="acluser">%s</b> má nyní na stránku <b class="aclpage">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_user_ns']             = 'Uživatel <b class="acluser">%s</b> má nyní na jmenný prostor <b class="aclns">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_group_id']            = 'Členové skupiny <b class="aclgroup">%s</b> mají nyní na stránku <b class="aclpage">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_group_ns']            = 'Členové skupiny <b class="aclgroup">%s</b> mají nyní na jmenný prostor <b class="aclns">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_choose_id']           = 'Prosím, <b>vložte uživatele nebo skupinu</b> ve formě uvedené výše, abyste mohli prohlížet a editovat množinu oprávnění pro stránku <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Prosím, <b>vložte uživatele nebo skupinu</b> ve formě uvedené výše, abyste mohli prohlížet a editovat množinu oprávnění pro jmenný prostor <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Poznámka: Tato oprávnění nebyla nastavena explicitně, ale jsou zděděna z jiné skupiny nebo z nadřazeného jmenného prostoru.';
$lang['p_isadmin']             = 'Poznámka: Vybraná skupina nebo uživatel má vždy plná oprávnění, protože je nastaven jako správce (superuser).';
$lang['p_include']             = 'Vyšší oprávnění zahrnují nižší oprávnění. Vytvořit, Nahrát a Smazat se vztahují jen k jmenným prostorů, nikoliv ke stránkám.';
$lang['current']               = 'Aktuální ACL pravidla';
$lang['where']                 = 'Stránka/Jmenný prostor';
$lang['who']                   = 'Uživatel/Skupina';
$lang['perm']                  = 'Oprávnění';
$lang['acl_perm0']             = 'Žádné';
$lang['acl_perm1']             = 'Čtení';
$lang['acl_perm2']             = 'Úpravy';
$lang['acl_perm4']             = 'Vytvoření';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Mazání';
$lang['acl_new']               = 'Přidat novou položku';
$lang['acl_mod']               = 'Editovat položku';

==> dokuwiki-2016.06.26a.tgz: dokuwiki/lib/plugins/acl/lang/cs/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author tomas@valenta.cz
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 * @author zbynek.krivka@seznam.cz
 * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
 * @author Jakub A. Těšínský (j@kub.cz)
 * @author mkucera66@seznam.cz
 */
$lang['admin_acl']             = 'Správa přístupových práv';
$lang['acl_group']             = 'Skupina:';
$lang['acl_user']              = 'Uživatel:';
$lang['acl_perms']             = 'Práva pro';
$lang['page']                  = 'Stránka';
$lang['namespace']             = 'Jmenný prostor';
$lang['btn_select']            = 'Vybrat';
$lang['p_user_id']             = 'Uživatel <b class="acluser">%s</b> má nyní na stránku <b class="aclpage">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_user_ns']             = 'Uživatel <b class="acluser">%s</b> má nyní na jmenný prostor <b class="aclns">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_group_id']            = 'Členové skupiny <b class="aclgroup">%s</b> mají nyní na stránku <b class="aclpage">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_group_ns']            = 'Členové skupiny <b class="aclgroup">%s</b> mají nyní na jmenný prostor <b class="aclns">%s</b> následující oprávnění: <i>%s</i>.';
$lang['p_choose_id']           = 'Prosím, <b>vložte uživatele nebo skupinu</b> ve formě uvedené výše, abyste mohli prohlížet a editovat množinu oprávnění pro stránku <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Prosím, <b>vložte uživatele nebo skupinu</b> ve formě uvedené výše, abyste mohli prohlížet a editovat množinu oprávnění pro jmenný prostor <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Poznámka: Tato oprávnění nebyla nastavena explicitně, ale jsou zděděna z jiné skupiny nebo z nadřazeného jmenného prostoru.';
$lang['p_isadmin']             = 'Poznámka: Vybraná skupina nebo uživatel má vždy plná oprávnění, protože je nastaven jako správce (superuser).';
$lang['p_include']             = 'Vyšší oprávnění zahrnují nižší oprávnění. Vytvořit, Nahrát a Smazat se vztahují jen k jmenným prostorů, nikoliv ke stránkám.';
$lang['current']               = 'Aktuální ACL pravidla';
$lang['where']                 = 'Stránka/Jmenný prostor';
$lang['who']                   = 'Uživatel/Skupina';
$lang['perm']                  = 'Oprávnění';
$lang['acl_perm0']             = 'Žádné';
$lang['acl_perm1']             = 'Čtení';
$lang['acl_perm2']             = 'Úpravy';
$lang['acl_perm4']             = 'Vytvoření';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Mazání';
$lang['acl_new']               = 'Přidat novou položku';
$lang['acl_mod']               = 'Editovat položku';
